@@ -2,6 +2,7 @@
 #'
 #' @param rope_percentage Value or vector of percentages in ROPE.
 #' @inheritParams format_p
+#' @inheritParams format_ci
 #'
 #' @return A formatted string.
 #'
@@ -9,14 +10,16 @@
 #' format_rope(c(0.02, 0.12, 0.357, 0))
 #' format_rope(c(0.02, 0.12, 0.357, 0), name = NULL)
 #' @export
-format_rope <- function(rope_percentage, name = "in ROPE") {
+format_rope <- function(rope_percentage, name = "in ROPE", digits = 2) {
   text <- ifelse(rope_percentage == 0, "0%",
-    ifelse(rope_percentage == 1, "100%",
-      paste0(format_value(rope_percentage * 100), "%")
+    ifelse(rope_percentage == 1, "100%", # nolint
+      format_value(rope_percentage, digits = digits, as_percent = TRUE)
     )
   )
+
   if (!is.null(name)) {
     text <- paste(text, name)
   }
+
   text
 }
