@@ -111,6 +111,9 @@ link_function.gls <- link_function.lm
 #' @export
 link_function.rq <- link_function.lm
 
+#' @export
+link_function.rqs <- link_function.lm
+
 #' @export
 link_function.rqss <- link_function.lm
 
@@ -314,8 +317,8 @@ link_function.psm <- link_function.tobit
 
 #' @export
 link_function.flexsurvreg <- function(x, ...) {
-  dist <- parse(text = safe_deparse(x$call))[[1]]$dist
-  .make_tobit_family(x, dist)$linkfun
+  distribution <- parse(text = safe_deparse(x$call))[[1]]$dist
+  .make_tobit_family(x, distribution)$linkfun
 }
 
 
@@ -341,6 +344,9 @@ link_function.clm2 <- link_function.clm
 #' @export
 link_function.clmm <- link_function.clm
 
+#' @export
+link_function.serp <- link_function.clm
+
 #' @export
 link_function.mixor <- link_function.clm
 
@@ -416,6 +422,17 @@ link_function.mira <- function(x, ...) {
 }
 
 
+#' @export
+link_function.averaging <- function(x, ...) {
+  ml <- attributes(x)$modelList
+  if (is.null(ml)) {
+    format_warning("Can't retrieve data. Please use `fit = TRUE` in `model.avg()`.")
+    return(NULL)
+  }
+  link_function(ml[[1]])
+}
+
+
 #' @export
 link_function.robmixglm <- function(x, ...) {
   switch(tolower(x$family),
@@ -746,16 +763,13 @@ link_function.brmsfit <- function(x, ...) {
   # do we have custom families?
   if (!is.null(fam$family) && (is.character(fam$family) && fam$family == "custom")) {
     il <- stats::make.link(fam$link)$linkfun
+  } else if ("linkfun" %in% names(fam)) {
+    il <- fam$linkfun
+  } else if ("link" %in% names(fam) && is.character(fam$link)) {
+    il <- stats::make.link(fam$link)$linkfun
   } else {
-    if ("linkfun" %in% names(fam)) {
-      il <- fam$linkfun
-    } else if ("link" %in% names(fam) && is.character(fam$link)) {
-      il <- stats::make.link(fam$link)$linkfun
-    } else {
-      ff <- get(fam$family, asNamespace("stats"))
-      il <- ff(fam$link)$linkfun
-    }
+    ff <- get(fam$family, asNamespace("stats"))
+    il <- ff(fam$link)$linkfun
   }
-
   il
 }
